@@ -1,3 +1,4 @@
+from dataclasses import dataclass
 from typing import List, Optional
 from pydantic import BaseModel
 from enum import Enum
@@ -22,13 +23,13 @@ class SegmentationAnnotation(BaseModel):
 
 
 class EventType(str, Enum):
-    MouseDown = 'mouse_down',
+    LeftMouseDown = 'left_mouse_down',
+    RightMouseDown = 'right_mouse_down',
     MouseMove = 'mouse_move',
-    MouseUp = 'mouse_up',
-
-    # TODO Introduce Keyboard Event?
-    Enter_Pressed = 'enter_pressed'
-    ESC_Pressed = 'esc_pressed'
+    LeftMouseUp = 'left_mouse_up',
+    RightMouseUp = 'right_mouse_up',
+    KeyUp = 'key_up',
+    KeyDown = 'key_down',
 
 
 class AnnotationData(BaseModel):
@@ -38,6 +39,9 @@ class AnnotationData(BaseModel):
     image_uuid: str
     category: Category
     is_shift_key_pressed: Optional[bool]
+    key_up: Optional[str] = None
+    key_down: Optional[str] = None
+
     # keyboard_modifiers: Optional[List[str]]
     # new_annotation_uuid: Optional[str]
     # edit_annotation_uuid: Optional[str]
