@@ -1,29 +1,32 @@
-from ..inbox_filter.relevants_filter import RelevantsFilter
+from . import Detections
+from . import Outbox
 from .rest.operation_mode import OperationMode
 from .detector import Detector
 from .rest import detect, upload, operation_mode
+from ..socket_response import SocketResponse
+from ..inbox_filter.relevants_filter import RelevantsFilter
 from ..rest import downloads
 from ..node import Node
 from ..status import State
 from ..status import DetectionStatus, State
 from ..context import Context
+from ..globals import GLOBALS
+from ..data_classes.category import Category
+from ..model_information import ModelInformation
 from fastapi.encoders import jsonable_encoder
 from fastapi_utils.tasks import repeat_every
-from typing import List, Optional, Union
-import shutil
+from typing import List, Union
 import os
 import contextlib
 import logging
-from learning_loop_node.globals import GLOBALS
 import subprocess
 import asyncio
 import numpy as np
 from fastapi_socketio import SocketManager
-from . import Detections
-from . import Outbox
 from threading import Thread
 from datetime import datetime
 from icecream import ic
+import shutil
 
 
 class DetectorNode(Node):
@@ -114,6 +117,8 @@ class DetectorNode(Node):
             if self.operation_mode != OperationMode.Idle:
                 logging.info(f'not checking for updates; operation mode is {self.operation_mode}')
                 return
+
+            self.status.reset_error('update_model')
             if self.target_model is None:
                 logging.info(f'not checking for updates; no target model selected')
                 return
@@ -126,28 +131,30 @@ class DetectorNode(Node):
                     target_model_folder = f'models/{self.target_model}'
                     shutil.rmtree(target_model_folder, ignore_errors=True)
                     os.makedirs(target_model_folder)
+
+                    await downloads.download_model(
+                        target_model_folder,
+                        Context(organization=self.organization, project=self.project),
+                        update_to_model_id,
+                        self.detector.model_format
+                    )
                     try:
-                        await downloads.download_model(
-                            target_model_folder,
-                            Context(organization=self.organization, project=self.project),
-                            update_to_model_id,
-                            self.detector.model_format
-                        )
-                        try:
-                            os.unlink(model_symlink)
-                            os.remove(model_symlink)
-                        except:
-                            pass
-                        os.symlink(target_model_folder, model_symlink)
-                        logging.info(f'Updated symlink for model to {os.readlink(model_symlink)}')
-                        self.reload(because='new model installed')
-                    except downloads.DownloadError as e:
-                        self.status.latest_error = f'download failed: {e.cause}'
+                        os.unlink(model_symlink)
+                        os.remove(model_symlink)
+                    except:
+                        pass
+                    os.symlink(target_model_folder, model_symlink)
+                    logging.info(f'Updated symlink for model to {os.readlink(model_symlink)}')
+
+                    await self.send_status()
+                    self.reload(because='new model installed')
             else:
                 logging.info('Versions are identic. Nothing to do.')
-        except Exception:
+        except Exception as e:
             logging.exception(f'check_for_update failed')
-            self.status.latest_error = 'could not check for model update'
+            msg = e.cause if isinstance(e, downloads.DownloadError) else str(e)
+            self.status.set_error('update_model', f'Could not update model: {msg}')
+            await self.send_status()
 
     async def send_status(self) -> Union[str, bool]:
         if not self.sio_client.connected:
@@ -157,22 +164,23 @@ class DetectorNode(Node):
             id=self.uuid,
             name=self.name,
             state=self.status.state,
-            latest_error=self.status.latest_error,
+            errors=self.status._errors,
             uptime=int((datetime.now() - self.startup_time).total_seconds()),
             operation_mode=self.operation_mode,
             current_model=self.detector.current_model.version if self.detector.current_model else None,
             target_model=self.target_model,
             model_format=self.detector.model_format,
         )
+
         logging.debug(f'sending status {status}')
-        response = await self.sio_client.call('update_detector', (self.organization, self.project, jsonable_encoder(status)), timeout=1)
-        try:
-            self.target_model = response['payload']['target_model_version']
-            logging.debug(f'After sending status. Target_model is {self.target_model}')
-            return response['payload']['target_model_id']
-        except:
-            logging.error('Could not send status to loop')
+        response = await self.sio_client.call('update_detector', (self.organization, self.project, jsonable_encoder(status)))
+        socket_response = SocketResponse.from_dict(response)
+        if not socket_response.success:
+            logging.error(f'Statusupdate failed: {response}')
             return False
+        self.target_model = socket_response.payload['target_model_version']
+        logging.debug(f'After sending status. Target_model is {self.target_model}')
+        return socket_response.payload['target_model_id']
 
     def get_state(self):
         return State.Online
@@ -193,6 +201,7 @@ class DetectorNode(Node):
     async def get_detections(self, raw_image, mac: str, tags: str):
         loop = asyncio.get_event_loop()
         detections = await loop.run_in_executor(None, self.detector.evaluate, raw_image)
+        detections = self.add_category_id_to_detections(self.detector.model_info, detections)
         info = "\n    ".join([str(d) for d in detections.box_detections])
         logging.info(f'detected:\n    {info}')
 
@@ -206,6 +215,21 @@ class DetectorNode(Node):
         for image in images:
             await loop.run_in_executor(None, lambda: self.outbox.save(image, Detections(), ['picked_by_system']))
 
+    def add_category_id_to_detections(self, model_info: ModelInformation, detections: Detections):
+        def find_category_id_by_name(categories: List[Category], category_name: str):
+            category_id = [category.id for category in categories if category.name == category_name]
+            return category_id[0] if category_id else ''
+
+        for box_detection in detections.box_detections:
+            category_name = box_detection.category_name
+            category_id = find_category_id_by_name(model_info.categories, category_name)
+            box_detection.category_id = category_id
+        for point_detection in detections.point_detections:
+            category_name = point_detection.category_name
+            category_id = find_category_id_by_name(model_info.categories, category_name)
+            point_detection.category_id = category_id
+        return detections
+
 
 @contextlib.contextmanager
 def pushd(new_dir):
